@@ -1,31 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2018 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the QtWaylandCompositor module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 or (at your option) any later version
-** approved by the KDE Free Qt Foundation. The licenses are as published by
-** the Free Software Foundation and appearing in the file LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2018 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include "linuxdmabufclientbufferintegration.h"
 #include "linuxdmabuf.h"
@@ -34,6 +8,7 @@
 #include <QtWaylandCompositor/private/qwayland-server-wayland.h>
 #include <qpa/qplatformnativeinterface.h>
 #include <QtOpenGL/QOpenGLTexture>
+#include <QtCore/QVarLengthArray>
 #include <QtGui/QGuiApplication>
 #include <QtGui/QOpenGLContext>
 
@@ -266,6 +241,12 @@ LinuxDmabufClientBufferIntegration::LinuxDmabufClientBufferIntegration()
 LinuxDmabufClientBufferIntegration::~LinuxDmabufClientBufferIntegration()
 {
     m_importedBuffers.clear();
+
+    if (egl_unbind_wayland_display != nullptr && m_displayBound) {
+        Q_ASSERT(m_wlDisplay != nullptr);
+        if (!egl_unbind_wayland_display(m_eglDisplay, m_wlDisplay))
+            qCWarning(qLcWaylandCompositorHardwareIntegration) << "eglUnbindWaylandDisplayWL failed";
+    }
 }
 
 void LinuxDmabufClientBufferIntegration::initializeHardware(struct ::wl_display *display)
@@ -319,14 +300,9 @@ void LinuxDmabufClientBufferIntegration::initializeHardware(struct ::wl_display
 
     if (egl_bind_wayland_display && egl_unbind_wayland_display) {
         m_displayBound = egl_bind_wayland_display(m_eglDisplay, display);
-        if (!m_displayBound) {
-            if (ignoreBindDisplay) {
-                qCWarning(qLcWaylandCompositorHardwareIntegration) << "Could not bind Wayland display. Ignoring.";
-            } else {
-                qCWarning(qLcWaylandCompositorHardwareIntegration) << "Failed to initialize EGL display. Could not bind Wayland display.";
-                return;
-            }
-        }
+        if (!m_displayBound)
+            qCDebug(qLcWaylandCompositorHardwareIntegration) << "Wayland display already bound by other client buffer integration.";
+        m_wlDisplay = display;
     }
 
     // request and sent formats/modifiers only after egl_display is bound
